sh_data = {
    'imports': [
        (0x4949c, 4, 9, '*.recvfrom'),
        (0x494a0, 4, 9, '*.div'),
        (0x494a4, 4, 9, '*.fflush'),
        (0x494a8, 4, 9, '*.lchown'),
        (0x494ac, 4, 9, '*.statfs'),
        (0x494b0, 4, 9, '*.atof'),
        (0x494b4, 4, 9, '*.dup2'),
        (0x494b8, 4, 9, '*.strcasecmp'),
        (0x494bc, 4, 9, '*.fgets'),
        (0x494c0, 4, 9, '*._IO_getc'),
        (0x494c4, 4, 9, '*.vsnprintf'),
        (0x494c8, 4, 9, '*.umount2'),
        (0x494cc, 4, 9, '*.uname'),
        (0x494d0, 4, 9, '*.setbuf'),
        (0x494d4, 4, 9, '*.strtoul'),
        (0x494d8, 4, 9, '*.__xstat'),
        (0x494dc, 4, 9, '*.fscanf'),
        (0x494e0, 4, 9, '*.getprotobyname'),
        (0x494e4, 4, 9, '*.syscall'),
        (0x494e8, 4, 9, '*.strptime'),
        (0x494ec, 4, 9, '*.mktime'),
        (0x494f0, 4, 9, '*.swapoff'),
        (0x494f4, 4, 9, '*.memset'),
        (0x494f8, 4, 9, '*.getservbyport'),
        (0x494fc, 4, 9, '*.__ctype_tolower_loc'),
        (0x49500, 4, 9, '*.closedir'),
        (0x49504, 4, 9, '*.putchar'),
        (0x49508, 4, 9, '*.isatty'),
        (0x4950c, 4, 9, '*.strchrnul'),
        (0x49510, 4, 9, '*._exit'),
        (0x49514, 4, 9, '*.strpbrk'),
        (0x49518, 4, 9, '*.strchr'),
        (0x4951c, 4, 9, '*.puts'),
        (0x49520, 4, 9, '*.getpagesize'),
        (0x49524, 4, 9, '*.xdr_int'),
        (0x49528, 4, 9, '*.bind'),
        (0x4952c, 4, 9, '*.getuid'),
        (0x49530, 4, 9, '*.abort'),
        (0x49534, 4, 9, '*.execvp'),
        (0x49538, 4, 9, '*.islower'),
        (0x4953c, 4, 9, '*.fseek'),
        (0x49540, 4, 9, '*.fchown'),
        (0x49544, 4, 9, '*.cfsetispeed'),
        (0x49548, 4, 9, '*.strncmp'),
        (0x4954c, 4, 9, '*.getdomainname'),
        (0x49550, 4, 9, '*.rand'),
        (0x49554, 4, 9, '*.sysinfo'),
        (0x49558, 4, 9, '*.mount'),
        (0x4955c, 4, 9, '*.strspn'),
        (0x49560, 4, 9, '*.fputs'),
        (0x49564, 4, 9, '*.chown'),
        (0x49568, 4, 9, '*.fcntl'),
        (0x4956c, 4, 9, '*.lseek'),
        (0x49570, 4, 9, '*.pututline'),
        (0x49574, 4, 9, '*.socket'),
        (0x49578, 4, 9, '*.strcat'),
        (0x4957c, 4, 9, '*.klogctl'),
        (0x49580, 4, 9, '*.pivot_root'),
        (0x49584, 4, 9, '*.fileno'),
        (0x49588, 4, 9, '*.cfgetospeed'),
        (0x4958c, 4, 9, '*.sethostname'),
        (0x49590, 4, 9, '*.getrlimit'),
        (0x49594, 4, 9, '*.addmntent'),
        (0x49598, 4, 9, '*.xdr_enum'),
        (0x4959c, 4, 9, '*.pclose'),
        (0x495a0, 4, 9, '*.isgraph'),
        (0x495a4, 4, 9, '*.rmdir'),
        (0x495a8, 4, 9, '*.getopt_long'),
        (0x495ac, 4, 9, '*.getgroups'),
        (0x495b0, 4, 9, '*.unsetenv'),
        (0x495b4, 4, 9, '*.gethostbyname'),
        (0x495b8, 4, 9, '*.fnmatch'),
        (0x495bc, 4, 9, '*.setmntent'),
        (0x495c0, 4, 9, '*.__libc_start_main'),
        (0x495c4, 4, 9, '*.sigaction'),
        (0x495c8, 4, 9, '*.syslog'),
        (0x495cc, 4, 9, '*.ftruncate'),
        (0x495d0, 4, 9, '*.isalpha'),
        (0x495d4, 4, 9, '*.memcpy'),
        (0x495d8, 4, 9, '*.sigemptyset'),
        (0x495dc, 4, 9, '*.closelog'),
        (0x495e0, 4, 9, '*.srand'),
        (0x495e4, 4, 9, '*.execlp'),
        (0x495e8, 4, 9, '*.setpgid'),
        (0x495ec, 4, 9, '*.gai_strerror'),
        (0x495f0, 4, 9, '*.vsyslog'),
        (0x495f4, 4, 9, '*.getutent'),
        (0x495f8, 4, 9, '*.dprintf'),
        (0x495fc, 4, 9, '*.raise'),
        (0x49600, 4, 9, '*.unlink'),
        (0x49604, 4, 9, '*.utime'),
        (0x49608, 4, 9, '*.clearenv'),
        (0x4960c, 4, 9, '*.toupper'),
        (0x49610, 4, 9, '*.umount'),
        (0x49614, 4, 9, '*.clntudp_create'),
        (0x49618, 4, 9, '*.scandir'),
        (0x4961c, 4, 9, '*.clnt_spcreateerror'),
        (0x49620, 4, 9, '*.tcflush'),
        (0x49624, 4, 9, '*.kill'),
        (0x49628, 4, 9, '*.popen'),
        (0x4962c, 4, 9, '*.longjmp'),
        (0x49630, 4, 9, '*.ioctl'),
        (0x49634, 4, 9, '*.signal'),
        (0x49638, 4, 9, '*.snprintf'),
        (0x4963c, 4, 9, '*.dirname'),
        (0x49640, 4, 9, '*.readdir'),
        (0x49644, 4, 9, '*.tcsetattr'),
        (0x49648, 4, 9, '*.getopt'),
        (0x4964c, 4, 9, '*.setsid'),
        (0x49650, 4, 9, '*.strcmp'),
        (0x49654, 4, 9, '*.tcsetpgrp'),
        (0x49658, 4, 9, '*.sendto'),
        (0x4965c, 4, 9, '*.strrchr'),
        (0x49660, 4, 9, '*.ctime'),
        (0x49664, 4, 9, '*.times'),
        (0x49668, 4, 9, '*.isupper'),
        (0x4966c, 4, 9, '*.getpid'),
        (0x49670, 4, 9, '*.crypt'),
        (0x49674, 4, 9, '*.strdup'),
        (0x49678, 4, 9, '*.perror'),
        (0x4967c, 4, 9, '*.write'),
        (0x49680, 4, 9, '*.getnetbyname'),
        (0x49684, 4, 9, '*.malloc'),
        (0x49688, 4, 9, '*.isprint'),
        (0x4968c, 4, 9, '*.ftello'),
        (0x49690, 4, 9, '*.vsprintf'),
        (0x49694, 4, 9, '*.execl'),
        (0x49698, 4, 9, '*.gettimeofday'),
        (0x4969c, 4, 9, '*.fchmod'),
        (0x496a0, 4, 9, '*.gethostname'),
        (0x496a4, 4, 9, '*.stime'),
        (0x496a8, 4, 9, '*.strlen'),
        (0x496ac, 4, 9, '*.symlink'),
        (0x496b0, 4, 9, '*.regcomp'),
        (0x496b4, 4, 9, '*.getgid'),
        (0x496b8, 4, 9, '*.regerror'),
        (0x496bc, 4, 9, '*.__ctype_toupper_loc'),
        (0x496c0, 4, 9, '*.sigfillset'),
        (0x496c4, 4, 9, '*.regfree'),
        (0x496c8, 4, 9, '*.__cxa_atexit'),
        (0x496cc, 4, 9, '*.vasprintf'),
        (0x496d0, 4, 9, '*.sync'),
        (0x496d4, 4, 9, '*.xdr_u_int'),
        (0x496d8, 4, 9, '*.setpgrp'),
        (0x496dc, 4, 9, '*.strstr'),
        (0x496e0, 4, 9, '*.isalnum'),
        (0x496e4, 4, 9, '*.__errno_location'),
        (0x496e8, 4, 9, '*.execve'),
        (0x496ec, 4, 9, '*.inet_addr'),
        (0x496f0, 4, 9, '*.mkdtemp'),
        (0x496f4, 4, 9, '*.hstrerror'),
        (0x496f8, 4, 9, '*.endmntent'),
        (0x496fc, 4, 9, '*.getmntent'),
        (0x49700, 4, 9, '*.setrlimit'),
        (0x49704, 4, 9, '*.strncpy'),
        (0x49708, 4, 9, '*.qsort'),
        (0x4970c, 4, 9, '*.execle'),
        (0x49710, 4, 9, '*.ftell'),
        (0x49714, 4, 9, '*.alphasort'),
        (0x49718, 4, 9, '*.vprintf'),
        (0x4971c, 4, 9, '*.strtol'),
        (0x49720, 4, 9, '*.tcgetpgrp'),
        (0x49724, 4, 9, '*.cfsetospeed'),
        (0x49728, 4, 9, '*.chroot'),
        (0x4972c, 4, 9, '*.strcpy'),
        (0x49730, 4, 9, '*.mkfifo'),
        (0x49734, 4, 9, '*.isascii'),
        (0x49738, 4, 9, '*.getcwd'),
        (0x4973c, 4, 9, '*.__h_errno_location'),
        (0x49740, 4, 9, '*.atoi'),
        (0x49744, 4, 9, '*.mkstemp'),
        (0x49748, 4, 9, '*.clnttcp_create'),
        (0x4974c, 4, 9, '*.__xmknod'),
        (0x49750, 4, 9, '*.realpath'),
        (0x49754, 4, 9, '*.freeaddrinfo'),
        (0x49758, 4, 9, '*.memchr'),
        (0x4975c, 4, 9, '*.bsearch'),
        (0x49760, 4, 9, '*.feof'),
        (0x49764, 4, 9, '*.sprintf'),
        (0x49768, 4, 9, '*._IO_putc'),
        (0x4976c, 4, 9, '*.strncasecmp'),
        (0x49770, 4, 9, '*.regexec'),
        (0x49774, 4, 9, '*.getenv'),
        (0x49778, 4, 9, '*.strsignal'),
        (0x4977c, 4, 9, '*.endutent'),
        (0x49780, 4, 9, '*.isblank'),
        (0x49784, 4, 9, '*.fprintf'),
        (0x49788, 4, 9, '*.openlog'),
        (0x4978c, 4, 9, '*.open'),
        (0x49790, 4, 9, '*.strftime'),
        (0x49794, 4, 9, '*.authunix_create_default'),
        (0x49798, 4, 9, '*.fsync'),
        (0x4979c, 4, 9, '*.umask'),
        (0x497a0, 4, 9, '*.chmod'),
        (0x497a4, 4, 9, '*.tcgetattr'),
        (0x497a8, 4, 9, '*.tolower'),
        (0x497ac, 4, 9, '*.sscanf'),
        (0x497b0, 4, 9, '*.readlink'),
        (0x497b4, 4, 9, '*.setvbuf'),
        (0x497b8, 4, 9, '*.setgid'),
        (0x497bc, 4, 9, '*.isspace'),
        (0x497c0, 4, 9, '*.getlogin'),
        (0x497c4, 4, 9, '*.inet_aton'),
        (0x497c8, 4, 9, '*.getpriority'),
        (0x497cc, 4, 9, '*.rewind'),
        (0x497d0, 4, 9, '*.sleep'),
        (0x497d4, 4, 9, '*.realloc'),
        (0x497d8, 4, 9, '*.mkdir'),
        (0x497dc, 4, 9, '*.setgroups'),
        (0x497e0, 4, 9, '*.setpriority'),
        (0x497e4, 4, 9, '*.fgetc'),
        (0x497e8, 4, 9, '*.utmpname'),
        (0x497ec, 4, 9, '*.cfgetispeed'),
        (0x497f0, 4, 9, '*.xdr_string'),
        (0x497f4, 4, 9, '*.getmntent_r'),
        (0x497f8, 4, 9, '*.access'),
        (0x497fc, 4, 9, '*.localtime'),
        (0x49800, 4, 9, '*.killpg'),
        (0x49804, 4, 9, '*.getnetbyaddr'),
        (0x49808, 4, 9, '*.xdr_opaque'),
        (0x4980c, 4, 9, '*.difftime'),
        (0x49810, 4, 9, '*.ferror'),
        (0x49814, 4, 9, '*.memmove'),
        (0x49818, 4, 9, '*.setutent'),
        (0x4981c, 4, 9, '*.exit'),
        (0x49820, 4, 9, '*.setsockopt'),
        (0x49824, 4, 9, '*.ispunct'),
        (0x49828, 4, 9, '*.link'),
        (0x4982c, 4, 9, '*.free'),
        (0x49830, 4, 9, '*.fdopen'),
        (0x49834, 4, 9, '*.strerror'),
        (0x49838, 4, 9, '*.select'),
        (0x4983c, 4, 9, '*.getaddrinfo'),
        (0x49840, 4, 9, '*.execv'),
        (0x49844, 4, 9, '*.clearerr'),
        (0x49848, 4, 9, '*.strtoll'),
        (0x4984c, 4, 9, '*.strncat'),
        (0x49850, 4, 9, '*.getchar'),
        (0x49854, 4, 9, '*.gethostbyaddr'),
        (0x49858, 4, 9, '*.inet_pton'),
        (0x4985c, 4, 9, '*.setuid'),
        (0x49860, 4, 9, '*.read'),
        (0x49864, 4, 9, '*.bindresvport'),
        (0x49868, 4, 9, '*.strtok'),
        (0x4986c, 4, 9, '*.updwtmp'),
        (0x49870, 4, 9, '*.time'),
        (0x49874, 4, 9, '*.vfprintf'),
        (0x49878, 4, 9, '*.inet_ntop'),
        (0x4987c, 4, 9, '*.fork'),
        (0x49880, 4, 9, '*.inet_ntoa'),
        (0x49884, 4, 9, '*.close'),
        (0x49888, 4, 9, '*.memcmp'),
        (0x4988c, 4, 9, '*._setjmp'),
        (0x49890, 4, 9, '*.vfork'),
        (0x49894, 4, 9, '*.wait3'),
        (0x49898, 4, 9, '*.putenv'),
        (0x4989c, 4, 9, '*.getpgrp'),
        (0x498a0, 4, 9, '*.swapon'),
        (0x498a4, 4, 9, '*.rename'),
        (0x498a8, 4, 9, '*.__fxstat'),
        (0x498ac, 4, 9, '*.setenv'),
        (0x498b0, 4, 9, '*.chdir'),
        (0x498b4, 4, 9, '*.getppid'),
        (0x498b8, 4, 9, '*.fclose'),
        (0x498bc, 4, 9, '*.fopen'),
        (0x498c0, 4, 9, '*.strsep'),
        (0x498c4, 4, 9, '*.geteuid'),
        (0x498c8, 4, 9, '*.strtod'),
        (0x498cc, 4, 9, '*.pmap_getmaps'),
        (0x498d0, 4, 9, '*.fread'),
        (0x498d4, 4, 9, '*.strcspn'),
        (0x498d8, 4, 9, '*.getegid'),
        (0x498dc, 4, 9, '*.sysconf'),
        (0x498e0, 4, 9, '*.__res_state'),
        (0x498e4, 4, 9, '*.xdr_array'),
        (0x498e8, 4, 9, '*.clnt_sperror'),
        (0x498ec, 4, 9, '*.__lxstat'),
        (0x498f0, 4, 9, '*.fputc'),
        (0x498f4, 4, 9, '*.pipe'),
        (0x498f8, 4, 9, '*._Jv_RegisterClasses'),
        (0x498fc, 4, 9, '*.system'),
        (0x49900, 4, 9, '*.strtoull'),
        (0x49904, 4, 9, '*.creat'),
        (0x49908, 4, 9, '*.__res_init'),
        (0x4990c, 4, 9, '*.printf'),
        (0x49910, 4, 9, '*.alarm'),
        (0x49914, 4, 9, '*.ttyname'),
        (0x49918, 4, 9, '*.xdr_bytes'),
        (0x4991c, 4, 9, '*.getnameinfo'),
        (0x49920, 4, 9, '*.wait'),
        (0x49924, 4, 9, '*.waitpid'),
        (0x49928, 4, 9, '*.pmap_getport'),
        (0x4992c, 4, 9, '*.opendir'),
        (0x49934, 4, 9, '*.__gmon_start__'),
    ],

    'exports' : [
        (0xb5f8, 0, 'recvfrom', 'sh'),
        (0xb604, 0, 'div', 'sh'),
        (0xb610, 0, 'fflush', 'sh'),
        (0xb61c, 0, 'lchown', 'sh'),
        (0xb628, 0, 'statfs', 'sh'),
        (0xb634, 0, 'atof', 'sh'),
        (0xb640, 0, 'dup2', 'sh'),
        (0xb64c, 0, 'strcasecmp', 'sh'),
        (0xb658, 0, 'fgets', 'sh'),
        (0xb664, 0, '_IO_getc', 'sh'),
        (0xb670, 0, 'vsnprintf', 'sh'),
        (0xb67c, 0, 'umount2', 'sh'),
        (0xb688, 0, 'uname', 'sh'),
        (0xb694, 0, 'setbuf', 'sh'),
        (0xb6a0, 0, 'strtoul', 'sh'),
        (0xb6ac, 0, '__xstat', 'sh'),
        (0xb6b8, 0, 'fscanf', 'sh'),
        (0xb6c4, 0, 'getprotobyname', 'sh'),
        (0xb6d0, 0, 'syscall', 'sh'),
        (0xb6dc, 0, 'strptime', 'sh'),
        (0xb6e8, 0, 'mktime', 'sh'),
        (0xb6f4, 0, 'swapoff', 'sh'),
        (0xb700, 0, 'memset', 'sh'),
        (0xb70c, 0, 'getservbyport', 'sh'),
        (0xb718, 0, '__ctype_tolower_loc', 'sh'),
        (0xb724, 0, 'closedir', 'sh'),
        (0xb730, 0, 'putchar', 'sh'),
        (0xb73c, 0, 'isatty', 'sh'),
        (0xb748, 0, 'strchrnul', 'sh'),
        (0xb754, 0, '_exit', 'sh'),
        (0xb760, 0, 'strpbrk', 'sh'),
        (0xb76c, 0, 'strchr', 'sh'),
        (0xb778, 0, 'puts', 'sh'),
        (0xb784, 0, 'getpagesize', 'sh'),
        (0xb790, 0, 'xdr_int', 'sh'),
        (0xb79c, 0, 'bind', 'sh'),
        (0xb7a8, 0, 'getuid', 'sh'),
        (0xb7b4, 0, 'abort', 'sh'),
        (0xb7c0, 0, 'execvp', 'sh'),
        (0xb7cc, 0, 'islower', 'sh'),
        (0xb7d8, 0, 'fseek', 'sh'),
        (0xb7e4, 0, 'fchown', 'sh'),
        (0xb7f0, 0, 'cfsetispeed', 'sh'),
        (0xb7fc, 0, 'strncmp', 'sh'),
        (0xb808, 0, 'getdomainname', 'sh'),
        (0xb814, 0, 'rand', 'sh'),
        (0xb820, 0, 'sysinfo', 'sh'),
        (0xb82c, 0, 'mount', 'sh'),
        (0xb838, 0, 'strspn', 'sh'),
        (0xb844, 0, 'fputs', 'sh'),
        (0xb850, 0, 'chown', 'sh'),
        (0xb85c, 0, 'fcntl', 'sh'),
        (0xb868, 0, 'lseek', 'sh'),
        (0xb874, 0, 'pututline', 'sh'),
        (0xb880, 0, 'socket', 'sh'),
        (0xb88c, 0, 'strcat', 'sh'),
        (0xb898, 0, 'klogctl', 'sh'),
        (0xb8a4, 0, 'pivot_root', 'sh'),
        (0xb8b0, 0, 'fileno', 'sh'),
        (0xb8bc, 0, 'cfgetospeed', 'sh'),
        (0xb8c8, 0, 'sethostname', 'sh'),
        (0xb8d4, 0, 'getrlimit', 'sh'),
        (0xb8e0, 0, 'addmntent', 'sh'),
        (0xb8ec, 0, 'xdr_enum', 'sh'),
        (0xb8f8, 0, 'pclose', 'sh'),
        (0xb904, 0, 'isgraph', 'sh'),
        (0xb910, 0, 'rmdir', 'sh'),
        (0xb91c, 0, 'getopt_long', 'sh'),
        (0xb928, 0, 'getgroups', 'sh'),
        (0xb934, 0, 'unsetenv', 'sh'),
        (0xb940, 0, 'gethostbyname', 'sh'),
        (0xb94c, 0, 'fnmatch', 'sh'),
        (0xb958, 0, 'setmntent', 'sh'),
        (0xb964, 0, '__libc_start_main', 'sh'),
        (0xb970, 0, 'sigaction', 'sh'),
        (0xb97c, 0, 'syslog', 'sh'),
        (0xb988, 0, 'ftruncate', 'sh'),
        (0xb994, 0, 'isalpha', 'sh'),
        (0xb9a0, 0, 'memcpy', 'sh'),
        (0xb9ac, 0, 'sigemptyset', 'sh'),
        (0xb9b8, 0, 'closelog', 'sh'),
        (0xb9c4, 0, 'srand', 'sh'),
        (0xb9d0, 0, 'execlp', 'sh'),
        (0xb9dc, 0, 'setpgid', 'sh'),
        (0xb9e8, 0, 'gai_strerror', 'sh'),
        (0xb9f4, 0, 'vsyslog', 'sh'),
        (0xba00, 0, 'getutent', 'sh'),
        (0xba0c, 0, 'dprintf', 'sh'),
        (0xba18, 0, 'raise', 'sh'),
        (0xba24, 0, 'unlink', 'sh'),
        (0xba30, 0, 'utime', 'sh'),
        (0xba3c, 0, 'clearenv', 'sh'),
        (0xba48, 0, 'toupper', 'sh'),
        (0xba54, 0, 'umount', 'sh'),
        (0xba60, 0, 'clntudp_create', 'sh'),
        (0xba6c, 0, 'scandir', 'sh'),
        (0xba78, 0, 'clnt_spcreateerror', 'sh'),
        (0xba84, 0, 'tcflush', 'sh'),
        (0xba90, 0, 'kill', 'sh'),
        (0xba9c, 0, 'popen', 'sh'),
        (0xbaa8, 0, 'longjmp', 'sh'),
        (0xbab4, 0, 'ioctl', 'sh'),
        (0xbac0, 0, 'signal', 'sh'),
        (0xbacc, 0, 'snprintf', 'sh'),
        (0xbad8, 0, 'dirname', 'sh'),
        (0xbae4, 0, 'readdir', 'sh'),
        (0xbaf0, 0, 'tcsetattr', 'sh'),
        (0xbafc, 0, 'getopt', 'sh'),
        (0xbb08, 0, 'setsid', 'sh'),
        (0xbb14, 0, 'strcmp', 'sh'),
        (0xbb20, 0, 'tcsetpgrp', 'sh'),
        (0xbb2c, 0, 'sendto', 'sh'),
        (0xbb38, 0, 'strrchr', 'sh'),
        (0xbb44, 0, 'ctime', 'sh'),
        (0xbb50, 0, 'times', 'sh'),
        (0xbb5c, 0, 'isupper', 'sh'),
        (0xbb68, 0, 'getpid', 'sh'),
        (0xbb74, 0, 'crypt', 'sh'),
        (0xbb80, 0, 'strdup', 'sh'),
        (0xbb8c, 0, 'perror', 'sh'),
        (0xbb98, 0, 'write', 'sh'),
        (0xbba4, 0, 'getnetbyname', 'sh'),
        (0xbbb0, 0, 'malloc', 'sh'),
        (0xbbbc, 0, 'isprint', 'sh'),
        (0xbbc8, 0, 'ftello', 'sh'),
        (0xbbd4, 0, 'vsprintf', 'sh'),
        (0xbbe0, 0, 'execl', 'sh'),
        (0xbbec, 0, 'gettimeofday', 'sh'),
        (0xbbf8, 0, 'fchmod', 'sh'),
        (0xbc04, 0, 'gethostname', 'sh'),
        (0xbc10, 0, 'stime', 'sh'),
        (0xbc1c, 0, 'strlen', 'sh'),
        (0xbc28, 0, 'symlink', 'sh'),
        (0xbc34, 0, 'regcomp', 'sh'),
        (0xbc40, 0, 'getgid', 'sh'),
        (0xbc4c, 0, 'regerror', 'sh'),
        (0xbc58, 0, '__ctype_toupper_loc', 'sh'),
        (0xbc64, 0, 'sigfillset', 'sh'),
        (0xbc70, 0, 'regfree', 'sh'),
        (0xbc7c, 0, '__cxa_atexit', 'sh'),
        (0xbc88, 0, 'vasprintf', 'sh'),
        (0xbc94, 0, 'sync', 'sh'),
        (0xbca0, 0, 'xdr_u_int', 'sh'),
        (0xbcac, 0, 'setpgrp', 'sh'),
        (0xbcb8, 0, 'strstr', 'sh'),
        (0xbcc4, 0, 'isalnum', 'sh'),
        (0xbcd0, 0, '__errno_location', 'sh'),
        (0xbcdc, 0, 'execve', 'sh'),
        (0xbce8, 0, 'inet_addr', 'sh'),
        (0xbcf4, 0, 'mkdtemp', 'sh'),
        (0xbd00, 0, 'hstrerror', 'sh'),
        (0xbd0c, 0, 'endmntent', 'sh'),
        (0xbd18, 0, 'getmntent', 'sh'),
        (0xbd24, 0, 'setrlimit', 'sh'),
        (0xbd30, 0, 'strncpy', 'sh'),
        (0xbd3c, 0, 'qsort', 'sh'),
        (0xbd48, 0, 'execle', 'sh'),
        (0xbd54, 0, 'ftell', 'sh'),
        (0xbd60, 0, 'alphasort', 'sh'),
        (0xbd6c, 0, 'vprintf', 'sh'),
        (0xbd78, 0, 'strtol', 'sh'),
        (0xbd84, 0, 'tcgetpgrp', 'sh'),
        (0xbd90, 0, 'cfsetospeed', 'sh'),
        (0xbd9c, 0, 'chroot', 'sh'),
        (0xbda8, 0, 'strcpy', 'sh'),
        (0xbdb4, 0, 'mkfifo', 'sh'),
        (0xbdc0, 0, 'isascii', 'sh'),
        (0xbdcc, 0, 'getcwd', 'sh'),
        (0xbdd8, 0, '__h_errno_location', 'sh'),
        (0xbde4, 0, 'atoi', 'sh'),
        (0xbdf0, 0, 'mkstemp', 'sh'),
        (0xbdfc, 0, 'clnttcp_create', 'sh'),
        (0xbe08, 0, '__xmknod', 'sh'),
        (0xbe14, 0, 'realpath', 'sh'),
        (0xbe20, 0, 'freeaddrinfo', 'sh'),
        (0xbe2c, 0, 'memchr', 'sh'),
        (0xbe38, 0, 'bsearch', 'sh'),
        (0xbe44, 0, 'feof', 'sh'),
        (0xbe50, 0, 'sprintf', 'sh'),
        (0xbe5c, 0, '_IO_putc', 'sh'),
        (0xbe68, 0, 'strncasecmp', 'sh'),
        (0xbe74, 0, 'regexec', 'sh'),
        (0xbe80, 0, 'getenv', 'sh'),
        (0xbe8c, 0, 'strsignal', 'sh'),
        (0xbe98, 0, 'endutent', 'sh'),
        (0xbea4, 0, 'isblank', 'sh'),
        (0xbeb0, 0, 'fprintf', 'sh'),
        (0xbebc, 0, 'openlog', 'sh'),
        (0xbec8, 0, 'open', 'sh'),
        (0xbed4, 0, 'strftime', 'sh'),
        (0xbee0, 0, 'authunix_create_default', 'sh'),
        (0xbeec, 0, 'fsync', 'sh'),
        (0xbef8, 0, 'umask', 'sh'),
        (0xbf04, 0, 'chmod', 'sh'),
        (0xbf10, 0, 'tcgetattr', 'sh'),
        (0xbf1c, 0, 'tolower', 'sh'),
        (0xbf28, 0, 'sscanf', 'sh'),
        (0xbf34, 0, 'readlink', 'sh'),
        (0xbf40, 0, 'setvbuf', 'sh'),
        (0xbf4c, 0, 'setgid', 'sh'),
        (0xbf58, 0, 'isspace', 'sh'),
        (0xbf64, 0, 'getlogin', 'sh'),
        (0xbf70, 0, 'inet_aton', 'sh'),
        (0xbf7c, 0, 'getpriority', 'sh'),
        (0xbf88, 0, 'rewind', 'sh'),
        (0xbf94, 0, 'sleep', 'sh'),
        (0xbfa0, 0, 'realloc', 'sh'),
        (0xbfac, 0, 'mkdir', 'sh'),
        (0xbfb8, 0, 'setgroups', 'sh'),
        (0xbfc4, 0, 'setpriority', 'sh'),
        (0xbfd0, 0, 'fgetc', 'sh'),
        (0xbfdc, 0, 'utmpname', 'sh'),
        (0xbfe8, 0, 'cfgetispeed', 'sh'),
        (0xbff4, 0, 'xdr_string', 'sh'),
        (0xc000, 0, 'getmntent_r', 'sh'),
        (0xc00c, 0, 'access', 'sh'),
        (0xc018, 0, 'localtime', 'sh'),
        (0xc024, 0, 'killpg', 'sh'),
        (0xc030, 0, 'getnetbyaddr', 'sh'),
        (0xc03c, 0, 'xdr_opaque', 'sh'),
        (0xc048, 0, 'difftime', 'sh'),
        (0xc054, 0, 'ferror', 'sh'),
        (0xc060, 0, 'memmove', 'sh'),
        (0xc06c, 0, 'setutent', 'sh'),
        (0xc078, 0, 'exit', 'sh'),
        (0xc084, 0, 'setsockopt', 'sh'),
        (0xc090, 0, 'ispunct', 'sh'),
        (0xc09c, 0, 'link', 'sh'),
        (0xc0a8, 0, 'free', 'sh'),
        (0xc0b4, 0, 'fdopen', 'sh'),
        (0xc0c0, 0, 'strerror', 'sh'),
        (0xc0cc, 0, 'select', 'sh'),
        (0xc0d8, 0, 'getaddrinfo', 'sh'),
        (0xc0e4, 0, 'execv', 'sh'),
        (0xc0f0, 0, 'clearerr', 'sh'),
        (0xc0fc, 0, 'strtoll', 'sh'),
        (0xc108, 0, 'strncat', 'sh'),
        (0xc114, 0, 'getchar', 'sh'),
        (0xc120, 0, 'gethostbyaddr', 'sh'),
        (0xc12c, 0, 'inet_pton', 'sh'),
        (0xc138, 0, 'setuid', 'sh'),
        (0xc144, 0, 'read', 'sh'),
        (0xc150, 0, 'bindresvport', 'sh'),
        (0xc15c, 0, 'strtok', 'sh'),
        (0xc168, 0, 'updwtmp', 'sh'),
        (0xc174, 0, 'time', 'sh'),
        (0xc180, 0, 'vfprintf', 'sh'),
        (0xc18c, 0, 'inet_ntop', 'sh'),
        (0xc198, 0, 'fork', 'sh'),
        (0xc1a4, 0, 'inet_ntoa', 'sh'),
        (0xc1b0, 0, 'close', 'sh'),
        (0xc1bc, 0, 'memcmp', 'sh'),
        (0xc1c8, 0, '_setjmp', 'sh'),
        (0xc1d4, 0, 'vfork', 'sh'),
        (0xc1e0, 0, 'wait3', 'sh'),
        (0xc1ec, 0, 'putenv', 'sh'),
        (0xc1f8, 0, 'getpgrp', 'sh'),
        (0xc204, 0, 'swapon', 'sh'),
        (0xc210, 0, 'rename', 'sh'),
        (0xc21c, 0, '__fxstat', 'sh'),
        (0xc228, 0, 'setenv', 'sh'),
        (0xc234, 0, 'chdir', 'sh'),
        (0xc240, 0, 'getppid', 'sh'),
        (0xc24c, 0, 'fclose', 'sh'),
        (0xc258, 0, 'fopen', 'sh'),
        (0xc264, 0, 'strsep', 'sh'),
        (0xc270, 0, 'geteuid', 'sh'),
        (0xc27c, 0, 'strtod', 'sh'),
        (0xc288, 0, 'pmap_getmaps', 'sh'),
        (0xc294, 0, 'fread', 'sh'),
        (0xc2a0, 0, 'strcspn', 'sh'),
        (0xc2ac, 0, 'getegid', 'sh'),
        (0xc2b8, 0, 'sysconf', 'sh'),
        (0xc2c4, 0, '__res_state', 'sh'),
        (0xc2d0, 0, 'xdr_array', 'sh'),
        (0xc2dc, 0, 'clnt_sperror', 'sh'),
        (0xc2e8, 0, '__lxstat', 'sh'),
        (0xc2f4, 0, 'fputc', 'sh'),
        (0xc300, 0, 'pipe', 'sh'),
        (0xc318, 0, 'system', 'sh'),
        (0xc324, 0, 'strtoull', 'sh'),
        (0xc330, 0, 'creat', 'sh'),
        (0xc33c, 0, '__res_init', 'sh'),
        (0xc348, 0, 'printf', 'sh'),
        (0xc354, 0, 'alarm', 'sh'),
        (0xc360, 0, 'ttyname', 'sh'),
        (0xc36c, 0, 'xdr_bytes', 'sh'),
        (0xc378, 0, 'getnameinfo', 'sh'),
        (0xc384, 0, 'wait', 'sh'),
        (0xc390, 0, 'waitpid', 'sh'),
        (0xc39c, 0, 'pmap_getport', 'sh'),
        (0xc3a8, 0, 'opendir', 'sh'),
        (0xc3b8, 0, '__entry', 'sh'),
        (0x210d5, 0, 'setpwent', 'sh'),
        (0x210ed, 0, 'endpwent', 'sh'),
        (0x21105, 0, 'setgrent', 'sh'),
        (0x2111d, 0, 'endgrent', 'sh'),
        (0x21135, 0, 'putpwent', 'sh'),
        (0x21185, 0, 'putgrent', 'sh'),
        (0x213b5, 0, 'initgroups', 'sh'),
        (0x2146d, 0, 'getgrent_r', 'sh'),
        (0x214c9, 0, 'getgrent', 'sh'),
        (0x214e9, 0, 'getpwent_r', 'sh'),
        (0x21545, 0, 'getpwent', 'sh'),
        (0x21565, 0, 'getgrgid_r', 'sh'),
        (0x215cd, 0, 'getgrgid', 'sh'),
        (0x215f1, 0, 'getpwuid_r', 'sh'),
        (0x21659, 0, 'getpw', 'sh'),
        (0x216b5, 0, 'getpwuid', 'sh'),
        (0x216d9, 0, 'getgrnam_r', 'sh'),
        (0x21745, 0, 'getgrnam', 'sh'),
        (0x21769, 0, 'getpwnam_r', 'sh'),
        (0x217d5, 0, 'getpwnam', 'sh'),
        (0x217f9, 0, 'fgetgrent_r', 'sh'),
        (0x21821, 0, 'fgetgrent', 'sh'),
        (0x21845, 0, 'fgetpwent_r', 'sh'),
        (0x2186d, 0, 'fgetpwent', 'sh'),
        (0x49da8, 1, 'stdout', 'sh'),
        (0x49dac, 1, '__environ', 'sh'),
        (0x49dac, 1, '_environ', 'sh'),
        (0x49dac, 1, 'environ', 'sh'),
        (0x49db0, 1, 'optind', 'sh'),
        (0x49db4, 1, 'optarg', 'sh'),
        (0x49db8, 1, 'stdin', 'sh'),
        (0x49dbc, 1, 'stderr', 'sh'),
    ],

    'relocs' : [
    ],

    'names' : [
        (0x809c, 'sh.ptr_ptr_init_function_0_00049394_0000809c'),
        (0x80a0, 'sh.ptr_ptr_init_function_0_00049394_000080a0'),
        (0xb5d0, 'sh.init_function'),
        (0xb5e4, 'sh.LazyLoaderTrampoline'),
        (0xb5f8, 'sh.plt_recvfrom'),
        (0xb604, 'sh.plt_div'),
        (0xb610, 'sh.plt_fflush'),
        (0xb61c, 'sh.plt_lchown'),
        (0xb628, 'sh.plt_statfs'),
        (0xb634, 'sh.plt_atof'),
        (0xb640, 'sh.plt_dup2'),
        (0xb64c, 'sh.plt_strcasecmp'),
        (0xb658, 'sh.plt_fgets'),
        (0xb664, 'sh.plt__IO_getc'),
        (0xb670, 'sh.plt_vsnprintf'),
        (0xb67c, 'sh.plt_umount2'),
        (0xb688, 'sh.plt_uname'),
        (0xb694, 'sh.plt_setbuf'),
        (0xb6a0, 'sh.plt_strtoul'),
        (0xb6ac, 'sh.plt___xstat'),
        (0xb6b8, 'sh.plt_fscanf'),
        (0xb6c4, 'sh.plt_getprotobyname'),
        (0xb6d0, 'sh.plt_syscall'),
        (0xb6dc, 'sh.plt_strptime'),
        (0xb6e8, 'sh.plt_mktime'),
        (0xb6f4, 'sh.plt_swapoff'),
        (0xb700, 'sh.plt_memset'),
        (0xb70c, 'sh.plt_getservbyport'),
        (0xb718, 'sh.plt___ctype_tolower_loc'),
        (0xb724, 'sh.plt_closedir'),
        (0xb730, 'sh.plt_putchar'),
        (0xb73c, 'sh.plt_isatty'),
        (0xb748, 'sh.plt_strchrnul'),
        (0xb754, 'sh.plt__exit'),
        (0xb760, 'sh.plt_strpbrk'),
        (0xb76c, 'sh.plt_strchr'),
        (0xb778, 'sh.plt_puts'),
        (0xb784, 'sh.plt_getpagesize'),
        (0xb790, 'sh.plt_xdr_int'),
        (0xb79c, 'sh.plt_bind'),
        (0xb7a8, 'sh.plt_getuid'),
        (0xb7b4, 'sh.plt_abort'),
        (0xb7c0, 'sh.plt_execvp'),
        (0xb7cc, 'sh.plt_islower'),
        (0xb7d8, 'sh.plt_fseek'),
        (0xb7e4, 'sh.plt_fchown'),
        (0xb7f0, 'sh.plt_cfsetispeed'),
        (0xb7fc, 'sh.plt_strncmp'),
        (0xb808, 'sh.plt_getdomainname'),
        (0xb814, 'sh.plt_rand'),
        (0xb820, 'sh.plt_sysinfo'),
        (0xb82c, 'sh.plt_mount'),
        (0xb838, 'sh.plt_strspn'),
        (0xb844, 'sh.plt_fputs'),
        (0xb850, 'sh.plt_chown'),
        (0xb85c, 'sh.plt_fcntl'),
        (0xb868, 'sh.plt_lseek'),
        (0xb874, 'sh.plt_pututline'),
        (0xb880, 'sh.plt_socket'),
        (0xb88c, 'sh.plt_strcat'),
        (0xb898, 'sh.plt_klogctl'),
        (0xb8a4, 'sh.plt_pivot_root'),
        (0xb8b0, 'sh.plt_fileno'),
        (0xb8bc, 'sh.plt_cfgetospeed'),
        (0xb8c8, 'sh.plt_sethostname'),
        (0xb8d4, 'sh.plt_getrlimit'),
        (0xb8e0, 'sh.plt_addmntent'),
        (0xb8ec, 'sh.plt_xdr_enum'),
        (0xb8f8, 'sh.plt_pclose'),
        (0xb904, 'sh.plt_isgraph'),
        (0xb910, 'sh.plt_rmdir'),
        (0xb91c, 'sh.plt_getopt_long'),
        (0xb928, 'sh.plt_getgroups'),
        (0xb934, 'sh.plt_unsetenv'),
        (0xb940, 'sh.plt_gethostbyname'),
        (0xb94c, 'sh.plt_fnmatch'),
        (0xb958, 'sh.plt_setmntent'),
        (0xb964, 'sh.plt___libc_start_main'),
        (0xb970, 'sh.plt_sigaction'),
        (0xb97c, 'sh.plt_syslog'),
        (0xb988, 'sh.plt_ftruncate'),
        (0xb994, 'sh.plt_isalpha'),
        (0xb9a0, 'sh.plt_memcpy'),
        (0xb9ac, 'sh.plt_sigemptyset'),
        (0xb9b8, 'sh.plt_closelog'),
        (0xb9c4, 'sh.plt_srand'),
        (0xb9d0, 'sh.plt_execlp'),
        (0xb9dc, 'sh.plt_setpgid'),
        (0xb9e8, 'sh.plt_gai_strerror'),
        (0xb9f4, 'sh.plt_vsyslog'),
        (0xba00, 'sh.plt_getutent'),
        (0xba0c, 'sh.plt_dprintf'),
        (0xba18, 'sh.plt_raise'),
        (0xba24, 'sh.plt_unlink'),
        (0xba30, 'sh.plt_utime'),
        (0xba3c, 'sh.plt_clearenv'),
        (0xba48, 'sh.plt_toupper'),
        (0xba54, 'sh.plt_umount'),
        (0xba60, 'sh.plt_clntudp_create'),
        (0xba6c, 'sh.plt_scandir'),
        (0xba78, 'sh.plt_clnt_spcreateerror'),
        (0xba84, 'sh.plt_tcflush'),
        (0xba90, 'sh.plt_kill'),
        (0xba9c, 'sh.plt_popen'),
        (0xbaa8, 'sh.plt_longjmp'),
        (0xbab4, 'sh.plt_ioctl'),
        (0xbac0, 'sh.plt_signal'),
        (0xbacc, 'sh.plt_snprintf'),
        (0xbad8, 'sh.plt_dirname'),
        (0xbae4, 'sh.plt_readdir'),
        (0xbaf0, 'sh.plt_tcsetattr'),
        (0xbafc, 'sh.plt_getopt'),
        (0xbb08, 'sh.plt_setsid'),
        (0xbb14, 'sh.plt_strcmp'),
        (0xbb20, 'sh.plt_tcsetpgrp'),
        (0xbb2c, 'sh.plt_sendto'),
        (0xbb38, 'sh.plt_strrchr'),
        (0xbb44, 'sh.plt_ctime'),
        (0xbb50, 'sh.plt_times'),
        (0xbb5c, 'sh.plt_isupper'),
        (0xbb68, 'sh.plt_getpid'),
        (0xbb74, 'sh.plt_crypt'),
        (0xbb80, 'sh.plt_strdup'),
        (0xbb8c, 'sh.plt_perror'),
        (0xbb98, 'sh.plt_write'),
        (0xbba4, 'sh.plt_getnetbyname'),
        (0xbbb0, 'sh.plt_malloc'),
        (0xbbbc, 'sh.plt_isprint'),
        (0xbbc8, 'sh.plt_ftello'),
        (0xbbd4, 'sh.plt_vsprintf'),
        (0xbbe0, 'sh.plt_execl'),
        (0xbbec, 'sh.plt_gettimeofday'),
        (0xbbf8, 'sh.plt_fchmod'),
        (0xbc04, 'sh.plt_gethostname'),
        (0xbc10, 'sh.plt_stime'),
        (0xbc1c, 'sh.plt_strlen'),
        (0xbc28, 'sh.plt_symlink'),
        (0xbc34, 'sh.plt_regcomp'),
        (0xbc40, 'sh.plt_getgid'),
        (0xbc4c, 'sh.plt_regerror'),
        (0xbc58, 'sh.plt___ctype_toupper_loc'),
        (0xbc64, 'sh.plt_sigfillset'),
        (0xbc70, 'sh.plt_regfree'),
        (0xbc7c, 'sh.plt___cxa_atexit'),
        (0xbc88, 'sh.plt_vasprintf'),
        (0xbc94, 'sh.plt_sync'),
        (0xbca0, 'sh.plt_xdr_u_int'),
        (0xbcac, 'sh.plt_setpgrp'),
        (0xbcb8, 'sh.plt_strstr'),
        (0xbcc4, 'sh.plt_isalnum'),
        (0xbcd0, 'sh.plt___errno_location'),
        (0xbcdc, 'sh.plt_execve'),
        (0xbce8, 'sh.plt_inet_addr'),
        (0xbcf4, 'sh.plt_mkdtemp'),
        (0xbd00, 'sh.plt_hstrerror'),
        (0xbd0c, 'sh.plt_endmntent'),
        (0xbd18, 'sh.plt_getmntent'),
        (0xbd24, 'sh.plt_setrlimit'),
        (0xbd30, 'sh.plt_strncpy'),
        (0xbd3c, 'sh.plt_qsort'),
        (0xbd48, 'sh.plt_execle'),
        (0xbd54, 'sh.plt_ftell'),
        (0xbd60, 'sh.plt_alphasort'),
        (0xbd6c, 'sh.plt_vprintf'),
        (0xbd78, 'sh.plt_strtol'),
        (0xbd84, 'sh.plt_tcgetpgrp'),
        (0xbd90, 'sh.plt_cfsetospeed'),
        (0xbd9c, 'sh.plt_chroot'),
        (0xbda8, 'sh.plt_strcpy'),
        (0xbdb4, 'sh.plt_mkfifo'),
        (0xbdc0, 'sh.plt_isascii'),
        (0xbdcc, 'sh.plt_getcwd'),
        (0xbdd8, 'sh.plt___h_errno_location'),
        (0xbde4, 'sh.plt_atoi'),
        (0xbdf0, 'sh.plt_mkstemp'),
        (0xbdfc, 'sh.plt_clnttcp_create'),
        (0xbe08, 'sh.plt___xmknod'),
        (0xbe14, 'sh.plt_realpath'),
        (0xbe20, 'sh.plt_freeaddrinfo'),
        (0xbe2c, 'sh.plt_memchr'),
        (0xbe38, 'sh.plt_bsearch'),
        (0xbe44, 'sh.plt_feof'),
        (0xbe50, 'sh.plt_sprintf'),
        (0xbe5c, 'sh.plt__IO_putc'),
        (0xbe68, 'sh.plt_strncasecmp'),
        (0xbe74, 'sh.plt_regexec'),
        (0xbe80, 'sh.plt_getenv'),
        (0xbe8c, 'sh.plt_strsignal'),
        (0xbe98, 'sh.plt_endutent'),
        (0xbea4, 'sh.plt_isblank'),
        (0xbeb0, 'sh.plt_fprintf'),
        (0xbebc, 'sh.plt_openlog'),
        (0xbec8, 'sh.plt_open'),
        (0xbed4, 'sh.plt_strftime'),
        (0xbee0, 'sh.plt_authunix_create_default'),
        (0xbeec, 'sh.plt_fsync'),
        (0xbef8, 'sh.plt_umask'),
        (0xbf04, 'sh.plt_chmod'),
        (0xbf10, 'sh.plt_tcgetattr'),
        (0xbf1c, 'sh.plt_tolower'),
        (0xbf28, 'sh.plt_sscanf'),
        (0xbf34, 'sh.plt_readlink'),
        (0xbf40, 'sh.plt_setvbuf'),
        (0xbf4c, 'sh.plt_setgid'),
        (0xbf58, 'sh.plt_isspace'),
        (0xbf64, 'sh.plt_getlogin'),
        (0xbf70, 'sh.plt_inet_aton'),
        (0xbf7c, 'sh.plt_getpriority'),
        (0xbf88, 'sh.plt_rewind'),
        (0xbf94, 'sh.plt_sleep'),
        (0xbfa0, 'sh.plt_realloc'),
        (0xbfac, 'sh.plt_mkdir'),
        (0xbfb8, 'sh.plt_setgroups'),
        (0xbfc4, 'sh.plt_setpriority'),
        (0xbfd0, 'sh.plt_fgetc'),
        (0xbfdc, 'sh.plt_utmpname'),
        (0xbfe8, 'sh.plt_cfgetispeed'),
        (0xbff4, 'sh.plt_xdr_string'),
        (0xc000, 'sh.plt_getmntent_r'),
        (0xc00c, 'sh.plt_access'),
        (0xc018, 'sh.plt_localtime'),
        (0xc024, 'sh.plt_killpg'),
        (0xc030, 'sh.plt_getnetbyaddr'),
        (0xc03c, 'sh.plt_xdr_opaque'),
        (0xc048, 'sh.plt_difftime'),
        (0xc054, 'sh.plt_ferror'),
        (0xc060, 'sh.plt_memmove'),
        (0xc06c, 'sh.plt_setutent'),
        (0xc078, 'sh.plt_exit'),
        (0xc084, 'sh.plt_setsockopt'),
        (0xc090, 'sh.plt_ispunct'),
        (0xc09c, 'sh.plt_link'),
        (0xc0a8, 'sh.plt_free'),
        (0xc0b4, 'sh.plt_fdopen'),
        (0xc0c0, 'sh.plt_strerror'),
        (0xc0cc, 'sh.plt_select'),
        (0xc0d8, 'sh.plt_getaddrinfo'),
        (0xc0e4, 'sh.plt_execv'),
        (0xc0f0, 'sh.plt_clearerr'),
        (0xc0fc, 'sh.plt_strtoll'),
        (0xc108, 'sh.plt_strncat'),
        (0xc114, 'sh.plt_getchar'),
        (0xc120, 'sh.plt_gethostbyaddr'),
        (0xc12c, 'sh.plt_inet_pton'),
        (0xc138, 'sh.plt_setuid'),
        (0xc144, 'sh.plt_read'),
        (0xc150, 'sh.plt_bindresvport'),
        (0xc15c, 'sh.plt_strtok'),
        (0xc168, 'sh.plt_updwtmp'),
        (0xc174, 'sh.plt_time'),
        (0xc180, 'sh.plt_vfprintf'),
        (0xc18c, 'sh.plt_inet_ntop'),
        (0xc198, 'sh.plt_fork'),
        (0xc1a4, 'sh.plt_inet_ntoa'),
        (0xc1b0, 'sh.plt_close'),
        (0xc1bc, 'sh.plt_memcmp'),
        (0xc1c8, 'sh.plt__setjmp'),
        (0xc1d4, 'sh.plt_vfork'),
        (0xc1e0, 'sh.plt_wait3'),
        (0xc1ec, 'sh.plt_putenv'),
        (0xc1f8, 'sh.plt_getpgrp'),
        (0xc204, 'sh.plt_swapon'),
        (0xc210, 'sh.plt_rename'),
        (0xc21c, 'sh.plt___fxstat'),
        (0xc228, 'sh.plt_setenv'),
        (0xc234, 'sh.plt_chdir'),
        (0xc240, 'sh.plt_getppid'),
        (0xc24c, 'sh.plt_fclose'),
        (0xc258, 'sh.plt_fopen'),
        (0xc264, 'sh.plt_strsep'),
        (0xc270, 'sh.plt_geteuid'),
        (0xc27c, 'sh.plt_strtod'),
        (0xc288, 'sh.plt_pmap_getmaps'),
        (0xc294, 'sh.plt_fread'),
        (0xc2a0, 'sh.plt_strcspn'),
        (0xc2ac, 'sh.plt_getegid'),
        (0xc2b8, 'sh.plt_sysconf'),
        (0xc2c4, 'sh.plt___res_state'),
        (0xc2d0, 'sh.plt_xdr_array'),
        (0xc2dc, 'sh.plt_clnt_sperror'),
        (0xc2e8, 'sh.plt___lxstat'),
        (0xc2f4, 'sh.plt_fputc'),
        (0xc300, 'sh.plt_pipe'),
        (0xc30c, 'sh.plt__Jv_RegisterClasses'),
        (0xc318, 'sh.plt_system'),
        (0xc324, 'sh.plt_strtoull'),
        (0xc330, 'sh.plt_creat'),
        (0xc33c, 'sh.plt___res_init'),
        (0xc348, 'sh.plt_printf'),
        (0xc354, 'sh.plt_alarm'),
        (0xc360, 'sh.plt_ttyname'),
        (0xc36c, 'sh.plt_xdr_bytes'),
        (0xc378, 'sh.plt_getnameinfo'),
        (0xc384, 'sh.plt_wait'),
        (0xc390, 'sh.plt_waitpid'),
        (0xc39c, 'sh.plt_pmap_getport'),
        (0xc3a8, 'sh.plt_opendir'),
        (0xc3b8, 'sh.__entry'),
        (0xc41c, 'sh.fini_function_0'),
        (0xc438, 'sh.init_function_0'),
        (0xc554, 'sh.ptr_stderr_0000c554'),
        (0xc8d0, 'sh.ptr_optind_0000c8d0'),
        (0xdf60, 'sh.ptr_optind_0000df60'),
        (0xe418, 'sh.ptr_stdout_0000e418'),
        (0xe41c, 'sh.ptr_stderr_0000e41c'),
        (0xe830, 'sh.ptr_optind_0000e830'),
        (0xe83c, 'sh.ptr_stdout_0000e83c'),
        (0xe844, 'sh.ptr_stdin_0000e844'),
        (0x107ec, 'sh.ptr_optind_000107ec'),
        (0x10930, 'sh.ptr_optind_00010930'),
        (0x10a54, 'sh.ptr_optind_00010a54'),
        (0x10c10, 'sh.ptr_stdout_00010c10'),
        (0x10c20, 'sh.ptr_optind_00010c20'),
        (0x10c2c, 'sh.ptr_stderr_00010c2c'),
        (0x10d00, 'sh.ptr_optind_00010d00'),
        (0x10ec8, 'sh.ptr_stdout_00010ec8'),
        (0x1105c, 'sh.ptr_optind_0001105c'),
        (0x110a4, 'sh.ptr_stdin_000110a4'),
        (0x113cc, 'sh.ptr_optind_000113cc'),
        (0x11440, 'sh.ptr_stderr_00011440'),
        (0x11940, 'sh.ptr_optind_00011940'),
        (0x11c3c, 'sh.ptr_optind_00011c3c'),
        (0x11ddc, 'sh.ptr_optind_00011ddc'),
        (0x11de0, 'sh.ptr___environ_00011de0'),
        (0x12014, 'sh.ptr_stderr_00012014'),
        (0x12610, 'sh.ptr_optarg_00012610'),
        (0x12618, 'sh.ptr_optind_00012618'),
        (0x12624, 'sh.ptr_stdin_00012624'),
        (0x12750, 'sh.ptr_optind_00012750'),
        (0x1289c, 'sh.ptr_optind_0001289c'),
        (0x13268, 'sh.ptr_stdout_00013268'),
        (0x132a8, 'sh.ptr_optind_000132a8'),
        (0x13340, 'sh.ptr_optind_00013340'),
        (0x13384, 'sh.ptr_optind_00013384'),
        (0x13420, 'sh.ptr_optind_00013420'),
        (0x13598, 'sh.ptr_optind_00013598'),
        (0x1359c, 'sh.ptr_stderr_0001359c'),
        (0x135fc, 'sh.ptr_stderr_000135fc'),
        (0x13adc, 'sh.ptr_optind_00013adc'),
        (0x13b5c, 'sh.ptr_optind_00013b5c'),
        (0x13e0c, 'sh.ptr_stdout_00013e0c'),
        (0x13e28, 'sh.ptr_optind_00013e28'),
        (0x13e2c, 'sh.ptr_stdin_00013e2c'),
        (0x13f20, 'sh.ptr_stdout_00013f20'),
        (0x14e4c, 'sh.ptr_optind_00014e4c'),
        (0x14f40, 'sh.ptr_optind_00014f40'),
        (0x14f44, 'sh.ptr_stdout_00014f44'),
        (0x14f4c, 'sh.ptr_stdin_00014f4c'),
        (0x157a8, 'sh.ptr_optind_000157a8'),
        (0x15b10, 'sh.ptr_optind_00015b10'),
        (0x15b94, 'sh.ptr_optind_00015b94'),
        (0x15bdc, 'sh.ptr_stdout_00015bdc'),
        (0x15be0, 'sh.ptr_stdin_00015be0'),
        (0x15d24, 'sh.ptr_optarg_00015d24'),
        (0x15d2c, 'sh.ptr_optind_00015d2c'),
        (0x15ec4, 'sh.ptr_optind_00015ec4'),
        # (0x1613c, 'sh.ptr_optind_0001613c'),
        (0x16198, 'sh.ptr_optind_00016198'),
        (0x16340, 'sh.ptr___environ_00016340'),
        (0x163f4, 'sh.ptr_optarg_000163f4'),
        (0x16404, 'sh.ptr_optind_00016404'),
        (0x166d8, 'sh.ptr_stdin_000166d8'),
        (0x17d44, 'sh.ptr_stdin_00017d44'),
        (0x18100, 'sh.ptr_stdout_00018100'),
        (0x184b8, 'sh.ptr_stdout_000184b8'),
        (0x193b4, 'sh.ptr_stdin_000193b4'),
        (0x193bc, 'sh.ptr_stdout_000193bc'),
        (0x193c4, 'sh.ptr_stderr_000193c4'),
        (0x193c8, 'sh.ptr___environ_000193c8'),
        (0x193d4, 'sh.ptr_optind_000193d4'),
        (0x1a458, 'sh.ptr_optind_0001a458'),
        (0x1a464, 'sh.ptr_stdout_0001a464'),
        (0x1a470, 'sh.ptr_stdin_0001a470'),
        (0x1a494, 'sh.ptr_stdout_0001a494'),
        (0x1aba8, 'sh.ptr_stdout_0001aba8'),
        (0x1ac18, 'sh.ptr_stdout_0001ac18'),
        (0x1ad64, 'sh.ptr_stdout_0001ad64'),
        (0x1ba18, 'sh.ptr_stdout_0001ba18'),
        (0x1c910, 'sh.ptr_optind_0001c910'),
        (0x1cc80, 'sh.ptr_optind_0001cc80'),
        (0x1d7d8, 'sh.ptr_optind_0001d7d8'),
        (0x1e544, 'sh.ptr_optind_0001e544'),
        (0x1e550, 'sh.ptr_stdin_0001e550'),
        (0x1e8dc, 'sh.ptr_optind_0001e8dc'),
        (0x1e8f4, 'sh.ptr_stderr_0001e8f4'),
        (0x1ebfc, 'sh.ptr_stderr_0001ebfc'),
        (0x1f294, 'sh.ptr_stdin_0001f294'),
        (0x1f2b4, 'sh.ptr_stdout_0001f2b4'),
        (0x1f8c4, 'sh.ptr_optarg_0001f8c4'),
        (0x1f8c8, 'sh.ptr_optind_0001f8c8'),
        (0x1f924, 'sh.ptr_optind_0001f924'),
        (0x20670, 'sh.ptr_stderr_00020670'),
        (0x207f0, 'sh.ptr_stdout_000207f0'),
        (0x207f4, 'sh.ptr_stderr_000207f4'),
        (0x208a8, 'sh.ptr_stdin_000208a8'),
        (0x20c20, 'sh.ptr_stdout_00020c20'),
        (0x20c44, 'sh.ptr_stdout_00020c44'),
        (0x20e98, 'sh.ptr_stdout_00020e98'),
        (0x210d5, 'sh.setpwent'),
        (0x210ed, 'sh.endpwent'),
        (0x21105, 'sh.setgrent'),
        (0x2111c, 'sh.endgrent'),
        (0x21135, 'sh.putpwent'),
        (0x21185, 'sh.putgrent'),
        (0x213b4, 'sh.initgroups'),
        (0x2146d, 'sh.getgrent_r'),
        (0x214c9, 'sh.getgrent'),
        (0x214e9, 'sh.getpwent_r'),
        (0x21545, 'sh.getpwent'),
        (0x21564, 'sh.getgrgid_r'),
        (0x215cc, 'sh.getgrgid'),
        (0x215f0, 'sh.getpwuid_r'),
        (0x21659, 'sh.getpw'),
        (0x216b4, 'sh.getpwuid'),
        (0x216d8, 'sh.getgrnam_r'),
        (0x21744, 'sh.getgrnam'),
        (0x21768, 'sh.getpwnam_r'),
        (0x217d4, 'sh.getpwnam'),
        (0x217f9, 'sh.fgetgrent_r'),
        (0x21821, 'sh.fgetgrent'),
        (0x21845, 'sh.fgetpwent_r'),
        (0x2186d, 'sh.fgetpwent'),
        (0x21cb4, 'sh.ptr_optind_00021cb4'),
        (0x224b4, 'sh.ptr_optind_000224b4'),
        (0x224e8, 'sh.ptr_stdin_000224e8'),
        (0x2266c, 'sh.ptr_stdout_0002266c'),
        (0x227e4, 'sh.ptr_optind_000227e4'),
        (0x22db4, 'sh.ptr_stderr_00022db4'),
        (0x22db8, 'sh.ptr_stdout_00022db8'),
        (0x22e38, 'sh.ptr_stdout_00022e38'),
        (0x23a74, 'sh.ptr_optind_00023a74'),
        (0x23b64, 'sh.ptr_optind_00023b64'),
        (0x23cc4, 'sh.ptr_optind_00023cc4'),
        (0x24a68, 'sh.ptr_optind_00024a68'),
        (0x24c84, 'sh.ptr_optind_00024c84'),
        (0x268c8, 'sh.ptr_optind_000268c8'),
        (0x269cc, 'sh.ptr_stdout_000269cc'),
        (0x26eb0, 'sh.ptr_optind_00026eb0'),
        (0x285d4, 'sh.ptr_stdout_000285d4'),
        (0x292a4, 'sh.ptr_stdout_000292a4'),
        (0x292d0, 'sh.ptr_stdout_000292d0'),
        (0x292d4, 'sh.ptr_stderr_000292d4'),
        (0x29364, 'sh.ptr_stdout_00029364'),
        (0x2938c, 'sh.ptr_stderr_0002938c'),
        (0x293a4, 'sh.ptr_stderr_000293a4'),
        (0x29640, 'sh.ptr_stderr_00029640'),
        (0x2a860, 'sh.ptr_stderr_0002a860'),
        (0x2aeac, 'sh.ptr_stderr_0002aeac'),
        (0x2b3a8, 'sh.ptr_stdout_0002b3a8'),
        (0x2b574, 'sh.ptr_stdout_0002b574'),
        (0x2f1b4, 'sh.ptr_stderr_0002f1b4'),
        (0x2f534, 'sh.ptr_stderr_0002f534'),
        (0x2f550, 'sh.ptr___environ_0002f550'),
        (0x2f978, 'sh.ptr_stdout_0002f978'),
        (0x30a14, 'sh.ptr_stdout_00030a14'),
        (0x30b1c, 'sh.ptr_stdout_00030b1c'),
        (0x30b70, 'sh.ptr_stdout_00030b70'),
        (0x31de8, 'sh.ptr_stdout_00031de8'),
        (0x32130, 'sh.ptr_optind_00032130'),
        (0x3213c, 'sh.ptr_stdin_0003213c'),
        (0x33000, 'sh.ptr_optind_00033000'),
        (0x332fc, 'sh.ptr_stdin_000332fc'),
        (0x33328, 'sh.ptr_stdout_00033328'),
        (0x34560, 'sh.ptr_optind_00034560'),
        (0x34840, 'sh.ptr_optind_00034840'),
        (0x34d80, 'sh.ptr_stdout_00034d80'),
        (0x34db4, 'sh.ptr_stdout_00034db4'),
        (0x351a4, 'sh.ptr_stderr_000351a4'),
        (0x353a0, 'sh.ptr_stdout_000353a0'),
        (0x354b0, 'sh.ptr_stdout_000354b0'),
        (0x370c8, 'sh.fini_function'),
        (0x25878, 'ptr_wstr_          _00025878'),
        (0x3d4e8, 'wstr_          _0003d4e8'),
        (0x49394, 'sh.ptr_init_function_0_00049394'),
        (0x49398, 'sh.ptr_fini_function_0_00049398'),
        (0x4949c, '*.recvfrom_0004949c'),
        (0x494a0, '*.div_000494a0'),
        (0x494a4, '*.fflush_000494a4'),
        (0x494a8, '*.lchown_000494a8'),
        (0x494ac, '*.statfs_000494ac'),
        (0x494b0, '*.atof_000494b0'),
        (0x494b4, '*.dup2_000494b4'),
        (0x494b8, '*.strcasecmp_000494b8'),
        (0x494bc, '*.fgets_000494bc'),
        (0x494c0, '*._IO_getc_000494c0'),
        (0x494c4, '*.vsnprintf_000494c4'),
        (0x494c8, '*.umount2_000494c8'),
        (0x494cc, '*.uname_000494cc'),
        (0x494d0, '*.setbuf_000494d0'),
        (0x494d4, '*.strtoul_000494d4'),
        (0x494d8, '*.__xstat_000494d8'),
        (0x494dc, '*.fscanf_000494dc'),
        (0x494e0, '*.getprotobyname_000494e0'),
        (0x494e4, '*.syscall_000494e4'),
        (0x494e8, '*.strptime_000494e8'),
        (0x494ec, '*.mktime_000494ec'),
        (0x494f0, '*.swapoff_000494f0'),
        (0x494f4, '*.memset_000494f4'),
        (0x494f8, '*.getservbyport_000494f8'),
        (0x494fc, '*.__ctype_tolower_loc_000494fc'),
        (0x49500, '*.closedir_00049500'),
        (0x49504, '*.putchar_00049504'),
        (0x49508, '*.isatty_00049508'),
        (0x4950c, '*.strchrnul_0004950c'),
        (0x49510, '*._exit_00049510'),
        (0x49514, '*.strpbrk_00049514'),
        (0x49518, '*.strchr_00049518'),
        (0x4951c, '*.puts_0004951c'),
        (0x49520, '*.getpagesize_00049520'),
        (0x49524, '*.xdr_int_00049524'),
        (0x49528, '*.bind_00049528'),
        (0x4952c, '*.getuid_0004952c'),
        (0x49530, '*.abort_00049530'),
        (0x49534, '*.execvp_00049534'),
        (0x49538, '*.islower_00049538'),
        (0x4953c, '*.fseek_0004953c'),
        (0x49540, '*.fchown_00049540'),
        (0x49544, '*.cfsetispeed_00049544'),
        (0x49548, '*.strncmp_00049548'),
        (0x4954c, '*.getdomainname_0004954c'),
        (0x49550, '*.rand_00049550'),
        (0x49554, '*.sysinfo_00049554'),
        (0x49558, '*.mount_00049558'),
        (0x4955c, '*.strspn_0004955c'),
        (0x49560, '*.fputs_00049560'),
        (0x49564, '*.chown_00049564'),
        (0x49568, '*.fcntl_00049568'),
        (0x4956c, '*.lseek_0004956c'),
        (0x49570, '*.pututline_00049570'),
        (0x49574, '*.socket_00049574'),
        (0x49578, '*.strcat_00049578'),
        (0x4957c, '*.klogctl_0004957c'),
        (0x49580, '*.pivot_root_00049580'),
        (0x49584, '*.fileno_00049584'),
        (0x49588, '*.cfgetospeed_00049588'),
        (0x4958c, '*.sethostname_0004958c'),
        (0x49590, '*.getrlimit_00049590'),
        (0x49594, '*.addmntent_00049594'),
        (0x49598, '*.xdr_enum_00049598'),
        (0x4959c, '*.pclose_0004959c'),
        (0x495a0, '*.isgraph_000495a0'),
        (0x495a4, '*.rmdir_000495a4'),
        (0x495a8, '*.getopt_long_000495a8'),
        (0x495ac, '*.getgroups_000495ac'),
        (0x495b0, '*.unsetenv_000495b0'),
        (0x495b4, '*.gethostbyname_000495b4'),
        (0x495b8, '*.fnmatch_000495b8'),
        (0x495bc, '*.setmntent_000495bc'),
        (0x495c0, '*.__libc_start_main_000495c0'),
        (0x495c4, '*.sigaction_000495c4'),
        (0x495c8, '*.syslog_000495c8'),
        (0x495cc, '*.ftruncate_000495cc'),
        (0x495d0, '*.isalpha_000495d0'),
        (0x495d4, '*.memcpy_000495d4'),
        (0x495d8, '*.sigemptyset_000495d8'),
        (0x495dc, '*.closelog_000495dc'),
        (0x495e0, '*.srand_000495e0'),
        (0x495e4, '*.execlp_000495e4'),
        (0x495e8, '*.setpgid_000495e8'),
        (0x495ec, '*.gai_strerror_000495ec'),
        (0x495f0, '*.vsyslog_000495f0'),
        (0x495f4, '*.getutent_000495f4'),
        (0x495f8, '*.dprintf_000495f8'),
        (0x495fc, '*.raise_000495fc'),
        (0x49600, '*.unlink_00049600'),
        (0x49604, '*.utime_00049604'),
        (0x49608, '*.clearenv_00049608'),
        (0x4960c, '*.toupper_0004960c'),
        (0x49610, '*.umount_00049610'),
        (0x49614, '*.clntudp_create_00049614'),
        (0x49618, '*.scandir_00049618'),
        (0x4961c, '*.clnt_spcreateerror_0004961c'),
        (0x49620, '*.tcflush_00049620'),
        (0x49624, '*.kill_00049624'),
        (0x49628, '*.popen_00049628'),
        (0x4962c, '*.longjmp_0004962c'),
        (0x49630, '*.ioctl_00049630'),
        (0x49634, '*.signal_00049634'),
        (0x49638, '*.snprintf_00049638'),
        (0x4963c, '*.dirname_0004963c'),
        (0x49640, '*.readdir_00049640'),
        (0x49644, '*.tcsetattr_00049644'),
        (0x49648, '*.getopt_00049648'),
        (0x4964c, '*.setsid_0004964c'),
        (0x49650, '*.strcmp_00049650'),
        (0x49654, '*.tcsetpgrp_00049654'),
        (0x49658, '*.sendto_00049658'),
        (0x4965c, '*.strrchr_0004965c'),
        (0x49660, '*.ctime_00049660'),
        (0x49664, '*.times_00049664'),
        (0x49668, '*.isupper_00049668'),
        (0x4966c, '*.getpid_0004966c'),
        (0x49670, '*.crypt_00049670'),
        (0x49674, '*.strdup_00049674'),
        (0x49678, '*.perror_00049678'),
        (0x4967c, '*.write_0004967c'),
        (0x49680, '*.getnetbyname_00049680'),
        (0x49684, '*.malloc_00049684'),
        (0x49688, '*.isprint_00049688'),
        (0x4968c, '*.ftello_0004968c'),
        (0x49690, '*.vsprintf_00049690'),
        (0x49694, '*.execl_00049694'),
        (0x49698, '*.gettimeofday_00049698'),
        (0x4969c, '*.fchmod_0004969c'),
        (0x496a0, '*.gethostname_000496a0'),
        (0x496a4, '*.stime_000496a4'),
        (0x496a8, '*.strlen_000496a8'),
        (0x496ac, '*.symlink_000496ac'),
        (0x496b0, '*.regcomp_000496b0'),
        (0x496b4, '*.getgid_000496b4'),
        (0x496b8, '*.regerror_000496b8'),
        (0x496bc, '*.__ctype_toupper_loc_000496bc'),
        (0x496c0, '*.sigfillset_000496c0'),
        (0x496c4, '*.regfree_000496c4'),
        (0x496c8, '*.__cxa_atexit_000496c8'),
        (0x496cc, '*.vasprintf_000496cc'),
        (0x496d0, '*.sync_000496d0'),
        (0x496d4, '*.xdr_u_int_000496d4'),
        (0x496d8, '*.setpgrp_000496d8'),
        (0x496dc, '*.strstr_000496dc'),
        (0x496e0, '*.isalnum_000496e0'),
        (0x496e4, '*.__errno_location_000496e4'),
        (0x496e8, '*.execve_000496e8'),
        (0x496ec, '*.inet_addr_000496ec'),
        (0x496f0, '*.mkdtemp_000496f0'),
        (0x496f4, '*.hstrerror_000496f4'),
        (0x496f8, '*.endmntent_000496f8'),
        (0x496fc, '*.getmntent_000496fc'),
        (0x49700, '*.setrlimit_00049700'),
        (0x49704, '*.strncpy_00049704'),
        (0x49708, '*.qsort_00049708'),
        (0x4970c, '*.execle_0004970c'),
        (0x49710, '*.ftell_00049710'),
        (0x49714, '*.alphasort_00049714'),
        (0x49718, '*.vprintf_00049718'),
        (0x4971c, '*.strtol_0004971c'),
        (0x49720, '*.tcgetpgrp_00049720'),
        (0x49724, '*.cfsetospeed_00049724'),
        (0x49728, '*.chroot_00049728'),
        (0x4972c, '*.strcpy_0004972c'),
        (0x49730, '*.mkfifo_00049730'),
        (0x49734, '*.isascii_00049734'),
        (0x49738, '*.getcwd_00049738'),
        (0x4973c, '*.__h_errno_location_0004973c'),
        (0x49740, '*.atoi_00049740'),
        (0x49744, '*.mkstemp_00049744'),
        (0x49748, '*.clnttcp_create_00049748'),
        (0x4974c, '*.__xmknod_0004974c'),
        (0x49750, '*.realpath_00049750'),
        (0x49754, '*.freeaddrinfo_00049754'),
        (0x49758, '*.memchr_00049758'),
        (0x4975c, '*.bsearch_0004975c'),
        (0x49760, '*.feof_00049760'),
        (0x49764, '*.sprintf_00049764'),
        (0x49768, '*._IO_putc_00049768'),
        (0x4976c, '*.strncasecmp_0004976c'),
        (0x49770, '*.regexec_00049770'),
        (0x49774, '*.getenv_00049774'),
        (0x49778, '*.strsignal_00049778'),
        (0x4977c, '*.endutent_0004977c'),
        (0x49780, '*.isblank_00049780'),
        (0x49784, '*.fprintf_00049784'),
        (0x49788, '*.openlog_00049788'),
        (0x4978c, '*.open_0004978c'),
        (0x49790, '*.strftime_00049790'),
        (0x49794, '*.authunix_create_default_00049794'),
        (0x49798, '*.fsync_00049798'),
        (0x4979c, '*.umask_0004979c'),
        (0x497a0, '*.chmod_000497a0'),
        (0x497a4, '*.tcgetattr_000497a4'),
        (0x497a8, '*.tolower_000497a8'),
        (0x497ac, '*.sscanf_000497ac'),
        (0x497b0, '*.readlink_000497b0'),
        (0x497b4, '*.setvbuf_000497b4'),
        (0x497b8, '*.setgid_000497b8'),
        (0x497bc, '*.isspace_000497bc'),
        (0x497c0, '*.getlogin_000497c0'),
        (0x497c4, '*.inet_aton_000497c4'),
        (0x497c8, '*.getpriority_000497c8'),
        (0x497cc, '*.rewind_000497cc'),
        (0x497d0, '*.sleep_000497d0'),
        (0x497d4, '*.realloc_000497d4'),
        (0x497d8, '*.mkdir_000497d8'),
        (0x497dc, '*.setgroups_000497dc'),
        (0x497e0, '*.setpriority_000497e0'),
        (0x497e4, '*.fgetc_000497e4'),
        (0x497e8, '*.utmpname_000497e8'),
        (0x497ec, '*.cfgetispeed_000497ec'),
        (0x497f0, '*.xdr_string_000497f0'),
        (0x497f4, '*.getmntent_r_000497f4'),
        (0x497f8, '*.access_000497f8'),
        (0x497fc, '*.localtime_000497fc'),
        (0x49800, '*.killpg_00049800'),
        (0x49804, '*.getnetbyaddr_00049804'),
        (0x49808, '*.xdr_opaque_00049808'),
        (0x4980c, '*.difftime_0004980c'),
        (0x49810, '*.ferror_00049810'),
        (0x49814, '*.memmove_00049814'),
        (0x49818, '*.setutent_00049818'),
        (0x4981c, '*.exit_0004981c'),
        (0x49820, '*.setsockopt_00049820'),
        (0x49824, '*.ispunct_00049824'),
        (0x49828, '*.link_00049828'),
        (0x4982c, '*.free_0004982c'),
        (0x49830, '*.fdopen_00049830'),
        (0x49834, '*.strerror_00049834'),
        (0x49838, '*.select_00049838'),
        (0x4983c, '*.getaddrinfo_0004983c'),
        (0x49840, '*.execv_00049840'),
        (0x49844, '*.clearerr_00049844'),
        (0x49848, '*.strtoll_00049848'),
        (0x4984c, '*.strncat_0004984c'),
        (0x49850, '*.getchar_00049850'),
        (0x49854, '*.gethostbyaddr_00049854'),
        (0x49858, '*.inet_pton_00049858'),
        (0x4985c, '*.setuid_0004985c'),
        (0x49860, '*.read_00049860'),
        (0x49864, '*.bindresvport_00049864'),
        (0x49868, '*.strtok_00049868'),
        (0x4986c, '*.updwtmp_0004986c'),
        (0x49870, '*.time_00049870'),
        (0x49874, '*.vfprintf_00049874'),
        (0x49878, '*.inet_ntop_00049878'),
        (0x4987c, '*.fork_0004987c'),
        (0x49880, '*.inet_ntoa_00049880'),
        (0x49884, '*.close_00049884'),
        (0x49888, '*.memcmp_00049888'),
        (0x4988c, '*._setjmp_0004988c'),
        (0x49890, '*.vfork_00049890'),
        (0x49894, '*.wait3_00049894'),
        (0x49898, '*.putenv_00049898'),
        (0x4989c, '*.getpgrp_0004989c'),
        (0x498a0, '*.swapon_000498a0'),
        (0x498a4, '*.rename_000498a4'),
        (0x498a8, '*.__fxstat_000498a8'),
        (0x498ac, '*.setenv_000498ac'),
        (0x498b0, '*.chdir_000498b0'),
        (0x498b4, '*.getppid_000498b4'),
        (0x498b8, '*.fclose_000498b8'),
        (0x498bc, '*.fopen_000498bc'),
        (0x498c0, '*.strsep_000498c0'),
        (0x498c4, '*.geteuid_000498c4'),
        (0x498c8, '*.strtod_000498c8'),
        (0x498cc, '*.pmap_getmaps_000498cc'),
        (0x498d0, '*.fread_000498d0'),
        (0x498d4, '*.strcspn_000498d4'),
        (0x498d8, '*.getegid_000498d8'),
        (0x498dc, '*.sysconf_000498dc'),
        (0x498e0, '*.__res_state_000498e0'),
        (0x498e4, '*.xdr_array_000498e4'),
        (0x498e8, '*.clnt_sperror_000498e8'),
        (0x498ec, '*.__lxstat_000498ec'),
        (0x498f0, '*.fputc_000498f0'),
        (0x498f4, '*.pipe_000498f4'),
        (0x498f8, '*._Jv_RegisterClasses_000498f8'),
        (0x498fc, '*.system_000498fc'),
        (0x49900, '*.strtoull_00049900'),
        (0x49904, '*.creat_00049904'),
        (0x49908, '*.__res_init_00049908'),
        (0x4990c, '*.printf_0004990c'),
        (0x49910, '*.alarm_00049910'),
        (0x49914, '*.ttyname_00049914'),
        (0x49918, '*.xdr_bytes_00049918'),
        (0x4991c, '*.getnameinfo_0004991c'),
        (0x49920, '*.wait_00049920'),
        (0x49924, '*.waitpid_00049924'),
        (0x49928, '*.pmap_getport_00049928'),
        (0x4992c, '*.opendir_0004992c'),
        (0x49934, '*.__gmon_start___00049934'),
        (0x49da8, 'sh.stdout'),
        (0x49dac, 'sh.__environ'),
        (0x49db0, 'sh.optind'),
        (0x49db4, 'sh.optarg'),
        (0x49db8, 'sh.stdin'),
        (0x49dbc, 'sh.stderr'),
    ],

    'pltgot': [
    ],

}
